clear

centers = readmatrix('centers_2.csv');
centers = centers(:,1:3);
center_lons = centers(:,1);
center_lons(center_lons > 180) = center_lons(center_lons > 180) - 360;
centers(:,1) = center_lons;

craters = readmatrix('craters_2.csv');
craters = craters(:,1:3);
crater_lons = craters(:,1);
crater_lons(crater_lons > 180) = crater_lons(crater_lons > 180) - 360;
craters(:,1) = crater_lons;

embedded_craters = readmatrix('embedded_craters.xlsx');
embedded_craters = embedded_craters(:,1:2);

climate_fans = readmatrix('climate_fan_bearing_craters.xlsx');
climate_fan_lons = climate_fans(:,1);
climate_fan_lons(climate_fan_lons > 180) = ...
    climate_fan_lons(climate_fan_lons > 180) - 360;
climate_fans(:,1) = climate_fan_lons;


a = shaperead('yellows.shp');
fans = shaperead('may2020_fan_apices_foredwin.shp');
fan_elevs = extractfield(fans,'apex_eleva')';
edwinlakes = shaperead('edwin_lakes.shp');
lakeslon = extractfield(edwinlakes,'CenterLong');
lakeslon(lakeslon > 180) = lakeslon(lakeslon > 180) - 360;
lakeslat = extractfield(edwinlakes,'CenterLati');

hascenter = zeros(length(a),1);
unitlats = zeros(length(a),1);
mean_unit_fan_elev = zeros(length(a),1);
hasfans = zeros(length(a),1);
haslakes = zeros(length(a),1);
hasclimatefans = zeros(length(a),1);
hasembed = zeros(length(a),1);
areas = zeros(length(a),1);
counts = zeros(length(a),1);
ids = extractfield(a,'OBJECTID')';

for i = 1:length(a)
    % Determine the center crater for the unit and if it has fans 
    dx = 1:(length(a(i).X)-1);
    centers_in = inpolygon(centers(:,1),centers(:,2),a(i).X(dx),a(i).Y(dx)); 
    if sum(centers_in) == 0
       center_distances = distance(centers(:,1),centers(:,2),...
           mean(a(i).X(dx),'omitnan'),mean(a(i).Y(dx),'omitnan')); 
       [~,idx] = min(center_distances);
       centers_in(idx) = 1;
    end
    hascenter(i) = min(1,sum(centers_in));
    hasfans_temp = inpolygon(extractfield(fans,'longitude'),...
        extractfield(fans,'latitude'),a(i).X(dx),a(i).Y(dx));
    mean_unit_fan_elev(i) = mean(fan_elevs(hasfans_temp==1));
    hasfans(i) = min(1,sum(hasfans_temp));
    haslakes(i) = min(1,sum(inpolygon(lakeslon,...
        lakeslat,a(i).X(dx),a(i).Y(dx))));
    hasclimatefans(i) = min(1,sum(inpolygon(climate_fans(:,1),climate_fans(:,2),...
        a(i).X(dx),a(i).Y(dx))));
    hasembed(i) = min(1,sum(inpolygon(embedded_craters(:,1),embedded_craters(:,2),...
        a(i).X(dx),a(i).Y(dx))));
    
    
    % Store the lats/lons of the outline and make a grid
    outline_lons = a(i).X(dx);
    outline_lats = a(i).Y(dx);
    
    unitlats(i) = mean(outline_lats);

    lon_grid_vals = linspace(min(outline_lons),max(outline_lons),100);
    lat_grid_vals = linspace(min(outline_lats),max(outline_lats),100);

    [finelon, finelat] = meshgrid(lon_grid_vals, lat_grid_vals);
    finelon = finelon(:);
    finelat = finelat(:);
    fine_in = inpolygon(finelon,finelat,a(i).X(dx),a(i).Y(dx));
    fineweight = cosd(finelat);

        
    % Determine which craters are on the unit
    % centers_in==1 bug corrected in "clean" folder version 9/18/20
    craters_in = inpolygon(craters(:,1),craters(:,2),a(i).X(dx),a(i).Y(dx));
    temp_craters = craters(craters_in==1,:);

    % Calculate r/R values for both the pixels and the craters
    centerval = centers(centers_in == 1,:);
    centerlon = centerval(1,1);
    centerlat = centerval(1,2);
    center_diam = centerval(1,3);

    fine_rr = (3389.5)*(pi/180)*(2000/center_diam)*distance(finelon,...
        finelat,centerlon,centerlat);
    crater_rr = (3389.5)*(pi/180)*(2000/center_diam)*distance(temp_craters(:,1),...
        temp_craters(:,2),centerlon,centerlat);

    % ANNULUS CHECKS EDITED IN NEXT 3 LINES ONLY 10/7/20 - O.G. is fine_rr <= 2
    areas(i) = a(i).SphArea_km*sum(fineweight(fine_rr >= 1 & fine_rr <= 2000 & fine_in == 1))/...
        sum(fineweight(fine_in == 1));
    counts(i) = length(crater_rr(crater_rr >= 1 & crater_rr <= 2000));

    % Plot results for sanity checks
    plot(centerlon,centerlat,'ko','markersize',5);
    hold on
    scatter(finelon,finelat,[],fine_rr);
    scatter(temp_craters(:,1),temp_craters(:,2),10,crater_rr,'filled');
    colorbar
  
    disp(i/length(a))
end
 
 save data_spatial_2_ac areas counts hascenter hasfans hasclimatefans hasembed haslakes ids unitlats mean_unit_fan_elev